PlotBubbleMatrix: PlotBubbleMatrix

Description Usage Arguments Value Author(s) Examples

Description

Plots a rate matrix such that circle area correlates with the rate

Usage

1
PlotBubbleMatrix(Q, main = "", special = Inf, cex = 1)

Arguments

Q

Instantaneous rate matrix

main

Optional plot title

special

If you want to highlight a particular element, input its number here

cex

Adjustment for text size

Value

None

Author(s)

Brian C. O'Meara

Examples

1
2
3
4
5
6
7
8
#A random sample transition matrix
Q <- matrix(runif(9), 3, 3)
diag(Q) <- 0
diag(Q) <- -rowSums(Q)
colnames(Q) <- c("A", "B", "C")
rownames(Q) <- c("A", "B", "C")
print(Q)
PlotBubbleMatrix(Q)

bomeara/RateViz documentation built on May 12, 2019, 11:34 p.m.