Description Usage Arguments Value Author(s) Examples
This plots a network showing transition rates between given states. It uses igraph for plotting.
1 | PlotTransitionNetwork(Q, main = "", layout.fn = layout.circle, ...)
|
Q |
Instantaneous rate matrix |
main |
Title for plot (optional) |
layout.fn |
Layout function from igraph. By default this uses a circle layout, but you may use other igraph functions. layout.fruchterman.reingold may generate a good looking graph. |
... |
Other arguments to pass to plot.igraph() |
No return
Brian C. O'Meara
1 2 3 4 5 6 7 8 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.