RateViz-package: Visualizations for instantaneous rate matrices

Description Details Author(s) Examples

Description

This package uses an instantaneous rate matrix (such as is used for models of DNA evolution, morphological character change over evolutionary history, and other areas) and summarizes it in various ways. These could include bubble plots, a network showing transitions, or calculations to figure out likely paths between two states.

Details

Package: RateViz
Type: Package
Version: 1.0
Date: 2015-02-17
License: GPL (>=2)

Author(s)

Brian C. O'Meara and Jeremy M. Beaulieu

Maintainer: Brian C. O'Meara <omeara.brian@gmail.com>

Examples

1
2
3
4
5
6
7
8
9
#A random sample transition matrix
Q <- matrix(runif(9), 3, 3)
diag(Q) <- 0
diag(Q) <- -rowSums(Q)
colnames(Q) <- c("A", "B", "C")
rownames(Q) <- c("A", "B", "C")
print(Q)
ComputePathwayProbability(Q, from=1, to=3)
PlotTransitionNetwork(Q)

bomeara/RateViz documentation built on May 12, 2019, 11:34 p.m.