Description Usage Arguments Value Author(s) References Examples
This implements the rate summary used in Zanne et al. 2014. Using the rate matrix, one can calculate
1 | ComputePathwayProbability(Q, from, to, correct.diag = TRUE, total.time = 1e+06)
|
Q |
Instantaneous rate matrix |
from |
Index (position) of start state in the matrix (i.e., the second character) |
to |
Index (position) of end state in the matrix |
correct.diag |
Normally the diagonal is the negative sum of the non-diagonal elements in a row. If TRUE, this verifies that this is so |
total.time |
A large enough time such that there is essentially no chance of remaining unchanged |
A vector with the probability of each path into the final state.
Brian C. O'Meara
Zanne et al. 2014
1 2 3 4 5 6 7 8 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.