Description Usage Arguments Value Author(s) Examples
Plots a rate matrix such that circle area correlates with the rate
1 | PlotBubbleMatrix(Q, main = "", special = Inf, cex = 1)
|
Q |
Instantaneous rate matrix |
main |
Optional plot title |
special |
If you want to highlight a particular element, input its number here |
cex |
Adjustment for text size |
None
Brian C. O'Meara
1 2 3 4 5 6 7 8 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.