Description Details Author(s) Examples
This package uses an instantaneous rate matrix (such as is used for models of DNA evolution, morphological character change over evolutionary history, and other areas) and summarizes it in various ways. These could include bubble plots, a network showing transitions, or calculations to figure out likely paths between two states.
| Package: | RateViz |
| Type: | Package |
| Version: | 1.0 |
| Date: | 2015-02-17 |
| License: | GPL (>=2) |
Brian C. O'Meara and Jeremy M. Beaulieu
Maintainer: Brian C. O'Meara <omeara.brian@gmail.com>
1 2 3 4 5 6 7 8 9 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.